@@ -270,18 +270,20 @@ def update_lib_contents(lib_directory, temp_dir, target_platform, file_path):
         except IndexError:
             pass
 
-        os.rename(os.path.join(temp_dir, 'lib'), os.path.join(temp_dir, 'Lib'))
+        shutil.move(os.path.join(temp_dir, 'lib'), os.path.join(temp_dir, 'Lib'))
 
     elif target_platform == 'unix':
-        for lib_file in glob.iglob('{}/**' .format(lib_directory)):
+        dest_dir = os.path.join(temp_dir, 'lib')
+        shutil.move(os.path.join(temp_dir, 'Lib'), dest_dir)
+        for lib_file in glob.iglob('{}/**' .format(dest_dir)):
             python_version = retrieve_python_version(file_path)
-            new_lib_file = re.sub('Lib', os.path.join('lib', python_version), lib_file)
-            os.renames(lib_file, new_lib_file)
-
-        try:
-            os.rename(os.path.join(temp_dir, 'Lib'), os.path.join(temp_dir, 'lib'))
-        except:
-            pass
+            py_folder = os.path.join(dest_dir, python_version)
+            new_lib_file = os.path.join(py_folder, os.path.basename(lib_file))
+            try:
+                os.makedirs(py_folder)
+            except:
+                pass
+            shutil.move(lib_file, new_lib_file)
 
 
 def update_executable_path(file_path, target_platform):
@@ -378,6 +380,8 @@ def update_paths_file(temp_dir, target_platform):
                     path['sha256'] = update_executable_sha(temp_dir, path['_path'])
                     path['size_in_bytes'] = update_executable_size(temp_dir, path['_path'])
 
+                path['_path'] = path['_path'].replace('\\', '/').replace('\\\\', '/')
+
             script_directory = os.path.join(temp_dir, 'Scripts')
             if os.path.isdir(script_directory):
                 for script in os.listdir(script_directory):
@@ -394,6 +398,8 @@ def update_paths_file(temp_dir, target_platform):
                     path['sha256'] = update_executable_sha(temp_dir, path['_path'])
                     path['size_in_bytes'] = update_executable_size(temp_dir, path['_path'])
 
+                path['_path'] = path['_path'].replace('\\', '/').replace('\\\\', '/')
+
                 if path['_path'].endswith(('.bat', '.exe')):
                     paths['paths'].remove(path)
 
@@ -556,7 +562,7 @@ def update_files_file(temp_dir, verbose):
             relative_dir = os.path.relpath(dirpath, temp_dir)
             filenames = [os.path.join(relative_dir, f) for f in filenames]
             for filename in filter_info_files(filenames, ''):
-                file_paths.append(filename)
+                file_paths.append(filename.replace('\\', '/').replace('\\\\', '/'))
                 if verbose:
                     print('Updating {}' .format(filename))
 
