@@ -30,7 +30,7 @@ from conda_build.config import get_or_merge_config
 from conda_build.conda_interface import text_type, iteritems, TemporaryDirectory, cc_conda_build
 from conda_build.license_family import allowed_license_families, guess_license_family
 from conda_build.utils import rm_rf, ensure_list
-from conda_build.variants import get_package_variants
+from conda_build.variants import get_package_variants, DEFAULT_VARIANTS
 
 SOURCE_META = """\
   {archive_keys}
@@ -655,11 +655,11 @@ def package_to_inputs_dict(output_dir, output_suffix, git_tag, package):
     new_location = join(output_dir, 'r-' + pkg_name + output_suffix)
     print(".. name: %s location: %s new_location: %s" % (pkg_name, location, new_location))
 
-    return dict({'pkg-name': pkg_name,
-                 'location': location,
-                 'old-git-rev': old_git_rev,
-                 'old-metadata': m,
-                 'new-location': new_location})
+    return {'pkg-name': pkg_name,
+            'location': location,
+            'old-git-rev': old_git_rev,
+            'old-metadata': m,
+            'new-location': new_location}
 
 
 def skeletonize(in_packages, output_dir=".", output_suffix="", add_maintainer=None, version=None,
@@ -674,7 +674,7 @@ def skeletonize(in_packages, output_dir=".", output_suffix="", add_maintainer=No
     if not cran_url:
         with TemporaryDirectory() as t:
             _variant = get_package_variants(t, config)[0]
-        cran_url = ensure_list(_variant.get('cran_mirror', "https://cran.r-project.org"))[0]
+        cran_url = ensure_list(_variant.get('cran_mirror', DEFAULT_VARIANTS['cran_mirror']))[0]
 
     if len(in_packages) > 1 and version_compare:
         raise ValueError("--version-compare only works with one package at a time")
@@ -857,16 +857,18 @@ def skeletonize(in_packages, output_dir=".", output_suffix="", add_maintainer=No
                     sha256 = hashlib.sha256()
                     cached_path = location
                 elif not is_github_url:
-                    filename = '{}_{}'.format(package, d['cran_version']) + archive_details['ext']
+                    filename_rendered = '{}_{}{}'.format(
+                        package, d['cran_version'], archive_details['ext'])
+                    filename = '{}_{{{{ version }}}}'.format(package) + archive_details['ext']
                     contrib_url = '{{{{ cran_mirror }}}}/{}'.format(archive_details['dir'])
                     contrib_url_rendered = cran_url + '/{}'.format(archive_details['dir'])
-                    package_url = contrib_url_rendered + filename
+                    package_url = contrib_url_rendered + filename_rendered
                     sha256 = hashlib.sha256()
                     print("Downloading {} from {}".format(archive_type, package_url))
                     # We may need to inspect the file later to determine which compilers are needed.
-                    cached_path, _ = source.download_to_cache(config.src_cache, '',
-                                                    dict({'url': package_url,
-                                                           'fn': archive_type + '-' + filename}))
+                    cached_path, _ = source.download_to_cache(
+                        config.src_cache, '',
+                        {'url': package_url, 'fn': archive_type + '-' + filename_rendered})
                 available_details = {}
                 available_details['selector'] = archive_details['selector']
                 if cached_path:
@@ -946,7 +948,7 @@ def skeletonize(in_packages, output_dir=".", output_suffix="", add_maintainer=No
                 else:
                     available_details['cranurl'] = ' ' + contrib_url + filename + sel_src
             if not is_github_url:
-                available_details['archive_keys'] = '{fn_key} {filename}{sel}\n' \
+                available_details['archive_keys'] = '{fn_key} {filename} {sel}\n' \
                                                     '  {url_key}{sel}' \
                                                     '    {cranurl}\n' \
                                                     '  {hash_entry}{sel}'.format(
@@ -1064,46 +1066,46 @@ def skeletonize(in_packages, output_dir=".", output_suffix="", add_maintainer=No
             # Put non-R dependencies first.
             if dep_type == 'build':
                 if need_c:
-                    deps.append("{indent}{{{{ compiler('c') }}}}        {sel}".format(
+                    deps.append("{indent}{{{{ compiler('c') }}}}      {sel}".format(
                         indent=INDENT, sel=sel_src_not_win))
                 if need_cxx:
-                    deps.append("{indent}{{{{ compiler('cxx') }}}}      {sel}".format(
+                    deps.append("{indent}{{{{ compiler('cxx') }}}}    {sel}".format(
                         indent=INDENT, sel=sel_src_not_win))
                 if need_f:
-                    deps.append("{indent}{{{{ compiler('fortran') }}}}  {sel}".format(
+                    deps.append("{indent}{{{{ compiler('fortran') }}}}{sel}".format(
                         indent=INDENT, sel=sel_src_not_win))
                 if use_rtools_win:
                     need_c = need_cxx = need_f = need_autotools = need_make = False
-                    deps.append("{indent}{{{{native}}}}rtools        {sel}".format(
+                    deps.append("{indent}{{{{native}}}}rtools      {sel}".format(
                         indent=INDENT, sel=sel_src_and_win))
-                    deps.append("{indent}{{{{native}}}}extsoft       {sel}".format(
+                    deps.append("{indent}{{{{native}}}}extsoft     {sel}".format(
                         indent=INDENT, sel=sel_src_and_win))
                 if need_c or need_cxx or need_f:
-                    deps.append("{indent}{{{{native}}}}toolchain        {sel}".format(
+                    deps.append("{indent}{{{{native}}}}toolchain      {sel}".format(
                         indent=INDENT, sel=sel_src_and_win))
                 if need_autotools or need_make or need_git:
-                    deps.append("{indent}{{{{posix}}}}filesystem        {sel}".format(
+                    deps.append("{indent}{{{{posix}}}}filesystem      {sel}".format(
                         indent=INDENT, sel=sel_src_and_win))
                 if need_git:
                     deps.append("{indent}{{{{posix}}}}git".format(indent=INDENT))
                 if need_autotools:
-                    deps.append("{indent}{{{{posix}}}}sed               {sel}".format(
+                    deps.append("{indent}{{{{posix}}}}sed             {sel}".format(
                         indent=INDENT, sel=sel_src_and_win))
-                    deps.append("{indent}{{{{posix}}}}grep              {sel}".format(
+                    deps.append("{indent}{{{{posix}}}}grep            {sel}".format(
                         indent=INDENT, sel=sel_src_and_win))
-                    deps.append("{indent}{{{{posix}}}}autoconf          {sel}".format(
+                    deps.append("{indent}{{{{posix}}}}autoconf        {sel}".format(
                         indent=INDENT, sel=sel_src))
-                    deps.append("{indent}{{{{posix}}}}automake-wrapper  {sel}".format(
+                    deps.append("{indent}{{{{posix}}}}automake-wrapper{sel}".format(
                         indent=INDENT, sel=sel_src_and_win))
-                    deps.append("{indent}{{{{posix}}}}automake          {sel}".format(
+                    deps.append("{indent}{{{{posix}}}}automake        {sel}".format(
                         indent=INDENT, sel=sel_src_and_win))
                     deps.append("{indent}{{{{posix}}}}pkg-config".format(indent=INDENT))
                 if need_make:
-                    deps.append("{indent}{{{{posix}}}}make              {sel}".format(
+                    deps.append("{indent}{{{{posix}}}}make            {sel}".format(
                         indent=INDENT, sel=sel_src))
             elif dep_type == 'run':
                 if need_c or need_cxx or need_f:
-                    deps.append("{indent}{{{{native}}}}gcc-libs         {sel}".format(
+                    deps.append("{indent}{{{{native}}}}gcc-libs       {sel}".format(
                         indent=INDENT, sel=sel_src_and_win))
 
             if dep_type == 'host' or dep_type == 'run':
